@@ -1,18 +1,8 @@
-import collections
-import sys
+import urllib.parse as urlparse
 from unittest import TestCase
-try:
-    import urlparse
-except ImportError:
-    import urllib.parse as urlparse
 
 
-# Somewhat consistent itemsequal between all python versions
-if sys.version_info[0] == 3:
-    TestCase.assertItemsEqual = TestCase.assertCountEqual
-
-
-# URL comparison where query param order is insignifcant
+# URL comparison where query param order is insignificant
 def url_equals(self, a, b, parse_fragment=False):
     parsed_a = urlparse.urlparse(a, allow_fragments=parse_fragment)
     parsed_b = urlparse.urlparse(b, allow_fragments=parse_fragment)
@@ -21,7 +11,7 @@ def url_equals(self, a, b, parse_fragment=False):
     if parse_fragment:
         fragment_a = urlparse.parse_qsl(parsed_a.fragment)
         fragment_b = urlparse.parse_qsl(parsed_b.fragment)
-        self.assertItemsEqual(fragment_a, fragment_b)
+        self.assertCountEqual(fragment_a, fragment_b)
     else:
         self.assertEqual(parsed_a.fragment, parsed_b.fragment)
     self.assertEqual(parsed_a.scheme, parsed_b.scheme)
@@ -32,10 +22,11 @@ def url_equals(self, a, b, parse_fragment=False):
     self.assertEqual(parsed_a.password, parsed_b.password)
     self.assertEqual(parsed_a.hostname, parsed_b.hostname)
     self.assertEqual(parsed_a.port, parsed_b.port)
-    self.assertItemsEqual(query_a, query_b)
+    self.assertCountEqual(query_a, query_b)
+
 
 TestCase.assertURLEqual = url_equals
 
 # Form body comparison where order is insignificant
-TestCase.assertFormBodyEqual = lambda self, a, b: self.assertItemsEqual(
+TestCase.assertFormBodyEqual = lambda self, a, b: self.assertCountEqual(
         urlparse.parse_qsl(a), urlparse.parse_qsl(b))
